@@ -1,4 +1,5 @@
 import logging
+import warnings
 
 import numpy as np
 import pandas as pd
@@ -17,6 +18,7 @@ from featuretools.utils.wrangle import (
     _check_timedelta,
     _dataframes_equal
 )
+from featuretools.variable_types.variable import find_variable_types
 
 logger = logging.getLogger('featuretools.entityset')
 
@@ -46,9 +48,9 @@ class Entity(object):
             df (pd.DataFrame): Dataframe providing the data for the
                 entity.
             entityset (EntitySet): Entityset for this Entity.
-            variable_types (dict[str -> dict[str -> type]]) : An entity's
+            variable_types (dict[str -> type/str/dict[str -> type]]) : An entity's
                 variable_types dict maps string variable ids to types (:class:`.Variable`)
-                or (type, kwargs) to pass keyword arguments to the Variable.
+                or type_string (str) or (type, kwargs) to pass keyword arguments to the Variable.
             index (str): Name of id column in the dataframe.
             time_index (str): Name of time column in the dataframe.
             secondary_time_index (dict[str -> str]): Dictionary mapping columns
@@ -210,7 +212,7 @@ class Entity(object):
         self.variables[self.variables.index(variable)] = new_variable
 
     def query_by_values(self, instance_vals, variable_id=None, columns=None,
-                        time_last=None, training_window=None):
+                        time_last=None, training_window=None, include_cutoff_time=True):
         """Query instances that have variable with given value
 
         Args:
@@ -223,6 +225,8 @@ class Entity(object):
             training_window (Timedelta, optional):
                 Window defining how much time before the cutoff time data
                 can be used when calculating features. If None, all data before cutoff time is used.
+            include_cutoff_time (bool):
+                If True, data at cutoff time are included in calculating features
 
         Returns:
             pd.DataFrame : instances that match constraints with ids in order of underlying dataframe
@@ -257,7 +261,8 @@ class Entity(object):
 
         df = self._handle_time(df=df,
                                time_last=time_last,
-                               training_window=training_window)
+                               training_window=training_window,
+                               include_cutoff_time=include_cutoff_time)
 
         if columns is not None:
             df = df[columns]
@@ -268,9 +273,9 @@ class Entity(object):
         """Extracts the variables from a dataframe
 
         Args:
-            variable_types (dict[str -> dict[str -> type]]) : An entity's
+            variable_types (dict[str -> types/str/dict[str -> type]]) : An entity's
                 variable_types dict maps string variable ids to types (:class:`.Variable`)
-                or (type, kwargs) to pass keyword arguments to the Variable.
+                or type_strings (str) or (type, kwargs) to pass keyword arguments to the Variable.
             index (str): Name of index column
             time_index (str or None): Name of time_index column
             secondary_time_index (dict[str: [str]]): Dictionary of secondary time columns
@@ -278,6 +283,16 @@ class Entity(object):
         """
         variables = []
         variable_types = variable_types.copy() or {}
+        string_to_class_map = find_variable_types()
+        for vid in variable_types.copy():
+            vtype = variable_types[vid]
+            if isinstance(vtype, str):
+                if vtype in string_to_class_map:
+                    variable_types[vid] = string_to_class_map[vtype]
+                else:
+                    variable_types[vid] = string_to_class_map['unknown']
+                    warnings.warn("Variable type {} was unrecognized, Unknown variable type was used instead".format(vtype))
+
         if index not in variable_types:
             variable_types[index] = vtypes.Index
 
@@ -346,7 +361,7 @@ class Entity(object):
         for variable in self.variables:
             # some heuristics to find basic 'where'-able variables
             if isinstance(variable, vtypes.Discrete):
-                variable.interesting_values = pd.Series()
+                variable.interesting_values = pd.Series(dtype=variable.entity.df[variable.id].dtype)
 
                 # TODO - consider removing this constraints
                 # don't add interesting values for entities in relationships
@@ -492,7 +507,7 @@ class Entity(object):
 
         return out_vals
 
-    def _handle_time(self, df, time_last=None, training_window=None):
+    def _handle_time(self, df, time_last=None, training_window=None, include_cutoff_time=True):
         """
         Filter a dataframe for all instances before time_last.
         If this entity does not have a time index, return the original
@@ -500,13 +515,22 @@ class Entity(object):
         """
         if self.time_index:
             if time_last is not None and not df.empty:
-                df = df[df[self.time_index] <= time_last]
+                if include_cutoff_time:
+                    df = df[df[self.time_index] <= time_last]
+                else:
+                    df = df[df[self.time_index] < time_last]
                 if training_window is not None:
                     training_window = _check_timedelta(training_window)
-                    mask = df[self.time_index] >= time_last - training_window
+                    if include_cutoff_time:
+                        mask = df[self.time_index] > time_last - training_window
+                    else:
+                        mask = df[self.time_index] >= time_last - training_window
                     if self.last_time_index is not None:
                         lti_slice = self.last_time_index.reindex(df.index)
-                        lti_mask = lti_slice >= time_last - training_window
+                        if include_cutoff_time:
+                            lti_mask = lti_slice > time_last - training_window
+                        else:
+                            lti_mask = lti_slice >= time_last - training_window
                         mask = mask | lti_mask
                     else:
                         logger.warning(
