@@ -37,7 +37,7 @@ class EntitySet(object):
             Args:
                 id (str) : Unique identifier to associate with this instance
 
-                entities (dict[str -> tuple(pd.DataFrame, str, str)]): Dictionary of
+                entities (dict[str -> tuple(pd.DataFrame, str, str, dict[str -> Variable])]): dictionary of
                     entities. Entries take the format
                     {entity id -> (dataframe, id column, (time_column), (variable_types))}.
                     Note that time_column and variable_types are optional.
@@ -432,8 +432,8 @@ class EntitySet(object):
             index (str, optional): Name of the variable used to index the entity.
                 If None, take the first column.
 
-            variable_types (dict[str -> Variable], optional):
-                Keys are of variable ids and values are variable types. Used to to
+            variable_types (dict[str -> Variable/str], optional):
+                Keys are of variable ids and values are variable types or type_strings. Used to to
                 initialize an entity's store.
 
             make_index (bool, optional) : If True, assume index does not
@@ -863,7 +863,7 @@ class EntitySet(object):
 
         """
         GRAPHVIZ_ERR_MSG = ('Please install graphviz to plot entity sets.' +
-                            ' (See https://docs.featuretools.com/getting_started/install.html#installing-graphviz for' +
+                            ' (See https://docs.featuretools.com/en/stable/getting_started/install.html#installing-graphviz for' +
                             ' details)')
         graphviz = import_or_raise("graphviz", GRAPHVIZ_ERR_MSG)
         # Try rendering a dummy graph to see if a working backend is installed
@@ -876,7 +876,7 @@ class EntitySet(object):
                 "  Mac OS: brew install graphviz\n" +
                 "  Linux (Ubuntu): sudo apt-get install graphviz\n" +
                 "  Windows: conda install python-graphviz\n" +
-                "  For more details visit: https://docs.featuretools.com/getting_started/install.html"
+                "  For more details visit: https://docs.featuretools.com/en/stable/getting_started/install.html"
             )
 
         if to_file:
