@@ -17,7 +17,7 @@ from featuretools.variable_types.variable import (
 BUCKET_NAME = "test-bucket"
 WRITE_KEY_NAME = "test-key"
 TEST_S3_URL = "s3://{}/{}".format(BUCKET_NAME, WRITE_KEY_NAME)
-TEST_FILE = "test_serialization_data_entityset_schema_2.0.0.tar"
+TEST_FILE = "test_serialization_data_entityset_schema_4.0.0.tar"
 S3_URL = "s3://featuretools-static/" + TEST_FILE
 URL = "https://featuretools-static.s3.amazonaws.com/" + TEST_FILE
 TEST_KEY = "test_access_key_es"
@@ -68,6 +68,12 @@ def test_variable_descriptions(es):
             assert variable.__eq__(_variable)
 
 
+def test_unknown_variable_description(es):
+    description = {'type': 'some_unknown_type', 'id': 'some_unknown_id', 'properties': {'name': 'some_unknown_type', 'interesting_values': '{}'}}
+    variable = deserialize.description_to_variable(description, entity=es.entities[0])
+    assert(variable.dtype == 'unknown')
+
+
 def test_entity_descriptions(es):
     _es = EntitySet(es.id)
     for entity in es.metadata.entities:
